Options for Table::view, and details about fields like expressions.
ViewConfig for the top level argument to Table::view.
expressions module for details about the ExprTK format.
Re-exports
pub use crate::proto::ColumnType;pub use crate::proto::SortOp;pub use expressions::*;pub use windows::*;
Modules
- expressions
- Perspective supports expression columns, which are virtual columns
calculated as part of the
crate::View, optionally using values from its underlyingcrate::Table’s columns. Such expression columns are defined in Perspective’s expression language, an extended version of ExprTK, which is itself quite similar (in design and features) to expressions in Excel. - windows
- Window columns are ordered, partitioned rolling computations over the rows
of a
crate::Table, declared per-crate::Viewlike expression columns - the analogue of SQL window functions. EachWindowSpecproduces a new output column, named by its key in thewindowsmap ({"name": {...spec}}, symmetric withexpressions), which may be used anywhere aTablecolumn can:columns,filter,sort,group_by, etc. Window columns update incrementally as theTableupdates, including rows outside an update batch whose window frames were affected by it.
Structs
- Default
Style Attributes - The default style configurations per type, as retrived by plugin.plugin_attributes
- Filter
- Plugin
Attributes - The data needed to populate a column’s settings.
- Plugin
Config - The configuration which is created as the result of calling plugin.save
- Sort
- Symbol
- Symbol
Attributes - View
Config - View
Config Update
Enums
- Aggregate
- Filter
Reducer - Filter
Term - Group
Rollup Mode - Scalar
- This type represents the ViewConfig serializable type, which must be JSON safe.
- SortDir