#[repr(i32)]pub enum WindowAggregate {
Show 14 variants
Sum = 0,
Avg = 1,
Count = 2,
Min = 3,
Max = 4,
Stddev = 5,
Var = 6,
First = 7,
Last = 8,
Lag = 9,
Lead = 10,
Diff = 11,
Rate = 12,
Ema = 13,
}Variants
Sum = 0
Avg = 1
Count = 2
Min = 3
Max = 4
Stddev = 5
Var = 6
First = 7
Last = 8
Lag = 9
Lead = 10
Diff = 11
Rate = 12
Ema = 13
Implementations
Sourceimpl WindowAggregate
impl WindowAggregate
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.