pub struct TableInitOptions {
pub name: Option<String>,
pub format: Option<TableReadFormat>,
pub index: Option<String>,
pub limit: Option<u32>,
pub page_to_disk: Option<bool>,
pub list_flatten: Option<ListFlatten>,
}Expand description
Options which impact the behavior of Client::table, as well as
subsequent calls to Table::update.
Fields
name: Option<String>format: Option<TableReadFormat>index: Option<String>This Table should use the column named by the index parameter as
the index, which causes Table::update and Client::table input
to either insert or update existing rows based on index column
value equality.
limit: Option<u32>This Table should be limited to limit rows, after which the
earliest rows will be overwritten (where earliest is defined as
relative to insertion order).
page_to_disk: Option<bool>Back this Table’s canonical data with the on-disk storage backend
instead of memory. On native targets this is a memory-mapped file; on
WASM it is OPFS (Worker only). Defaults to in-memory.
list_flatten: Option<ListFlatten>How Arrow LIST and JSON Array columns are ingested. zip (the
default) and cartesian expand a row into one row per list element,
and are incompatible with index, as the rows of an expansion
repeat their index. stringify encodes each list as a JSON array in
a single string column instead.
Implementations