pub struct Features(/* private fields */);Expand description
Metadata about what features are supported by the Server to which this
Client connects.
Implementations
Sourceimpl Features
impl Features
pub fn get_group_rollup_modes(&self) -> Vec<GroupRollupMode>
Methods from Deref<Target = GetFeaturesResp>
pub fn default_op(&self, col_type: ColumnType) -> Option<&str>
Sourcepub fn group_rollup_mode(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<GroupRollupMode>>
pub fn group_rollup_mode( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<GroupRollupMode>>
Returns an iterator which yields the valid enum values contained in group_rollup_mode.